[llvm-commits] [llvm] r92322 - in /llvm/trunk: include/llvm/Analysis/DebugInfo.h include/llvm/IntrinsicInst.h include/llvm/Metadata.h lib/Analysis/DebugInfo.cpp lib/Bitcode/Writer/BitcodeWriter.cpp lib/Bitcode/Writer/ValueEnumerator.cpp lib/Linker/LinkModules.cpp lib/Transforms/Utils/CloneFunction.cpp lib/VMCore/AsmWriter.cpp lib/VMCore/IntrinsicInst.cpp lib/VMCore/Metadata.cpp lib/VMCore/Verifier.cpp unittests/VMCore/MetadataTest.cpp

Chris Lattner sabre at nondot.org
Wed Dec 30 17:22:30 PST 2009


Author: lattner
Date: Wed Dec 30 19:22:29 2009
New Revision: 92322

URL: http://llvm.org/viewvc/llvm-project?rev=92322&view=rev
Log:
rename "elements" of metadata to "operands".  "Elements" are
things that occur in types.  "operands" are things that occur
in values.

Modified:
    llvm/trunk/include/llvm/Analysis/DebugInfo.h
    llvm/trunk/include/llvm/IntrinsicInst.h
    llvm/trunk/include/llvm/Metadata.h
    llvm/trunk/lib/Analysis/DebugInfo.cpp
    llvm/trunk/lib/Bitcode/Writer/BitcodeWriter.cpp
    llvm/trunk/lib/Bitcode/Writer/ValueEnumerator.cpp
    llvm/trunk/lib/Linker/LinkModules.cpp
    llvm/trunk/lib/Transforms/Utils/CloneFunction.cpp
    llvm/trunk/lib/VMCore/AsmWriter.cpp
    llvm/trunk/lib/VMCore/IntrinsicInst.cpp
    llvm/trunk/lib/VMCore/Metadata.cpp
    llvm/trunk/lib/VMCore/Verifier.cpp
    llvm/trunk/unittests/VMCore/MetadataTest.cpp

Modified: llvm/trunk/include/llvm/Analysis/DebugInfo.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/Analysis/DebugInfo.h?rev=92322&r1=92321&r2=92322&view=diff

==============================================================================
--- llvm/trunk/include/llvm/Analysis/DebugInfo.h (original)
+++ llvm/trunk/include/llvm/Analysis/DebugInfo.h Wed Dec 30 19:22:29 2009
@@ -369,19 +369,19 @@
     unsigned isDefinition() const      { return getUnsignedField(10); }
 
     unsigned getVirtuality() const {
-      if (DbgNode->getNumElements() < 14)
+      if (DbgNode->getNumOperands() < 14)
         return 0;
       return getUnsignedField(11);
     }
 
     unsigned getVirtualIndex() const { 
-      if (DbgNode->getNumElements() < 14)
+      if (DbgNode->getNumOperands() < 14)
         return 0;
       return getUnsignedField(12);
     }
 
     DICompositeType getContainingType() const {
-      assert (DbgNode->getNumElements() >= 14 && "Invalid type!");
+      assert (DbgNode->getNumOperands() >= 14 && "Invalid type!");
       return getFieldAs<DICompositeType>(13);
     }
 
@@ -439,7 +439,7 @@
       return getNumAddrElements() > 0;
     }
 
-    unsigned getNumAddrElements() const { return DbgNode->getNumElements()-6; }
+    unsigned getNumAddrElements() const { return DbgNode->getNumOperands()-6; }
 
     uint64_t getAddrElement(unsigned Idx) const {
       return getUInt64Field(Idx+6);

Modified: llvm/trunk/include/llvm/IntrinsicInst.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/IntrinsicInst.h?rev=92322&r1=92321&r2=92322&view=diff

==============================================================================
--- llvm/trunk/include/llvm/IntrinsicInst.h (original)
+++ llvm/trunk/include/llvm/IntrinsicInst.h Wed Dec 30 19:22:29 2009
@@ -98,8 +98,8 @@
       return unsigned(cast<ConstantInt>(getOperand(2))->getZExtValue());
     }
     
-    Value* getFileName() const;
-    Value* getDirectory() const;
+    Value *getFileName() const;
+    Value *getDirectory() const;
 
     // Methods for support type inquiry through isa, cast, and dyn_cast:
     static inline bool classof(const DbgStopPointInst *) { return true; }
@@ -175,8 +175,8 @@
   /// DbgValueInst - This represents the llvm.dbg.value instruction.
   ///
   struct DbgValueInst : public DbgInfoIntrinsic {
-    Value *getValue()  const {
-      return cast<MDNode>(getOperand(1))->getElement(0);
+    Value *getValue() const {
+      return cast<MDNode>(getOperand(1))->getOperand(0);
     }
     Value *getOffset() const { return getOperand(2); }
     MDNode *getVariable() const { return cast<MDNode>(getOperand(3)); }

Modified: llvm/trunk/include/llvm/Metadata.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/Metadata.h?rev=92322&r1=92321&r2=92322&view=diff

==============================================================================
--- llvm/trunk/lib/Analysis/DebugInfo.cpp (original)
+++ llvm/trunk/lib/Analysis/DebugInfo.cpp Wed Dec 30 19:22:29 2009
@@ -83,8 +83,8 @@
   if (DbgNode == 0)
     return StringRef();
 
-  if (Elt < DbgNode->getNumElements())
-    if (MDString *MDS = dyn_cast_or_null<MDString>(DbgNode->getElement(Elt)))
+  if (Elt < DbgNode->getNumOperands())
+    if (MDString *MDS = dyn_cast_or_null<MDString>(DbgNode->getOperand(Elt)))
       return MDS->getString();
 
   return StringRef();
@@ -94,8 +94,8 @@
   if (DbgNode == 0)
     return 0;
 
-  if (Elt < DbgNode->getNumElements())
-    if (ConstantInt *CI = dyn_cast<ConstantInt>(DbgNode->getElement(Elt)))
+  if (Elt < DbgNode->getNumOperands())
+    if (ConstantInt *CI = dyn_cast<ConstantInt>(DbgNode->getOperand(Elt)))
       return CI->getZExtValue();
 
   return 0;
@@ -105,8 +105,8 @@
   if (DbgNode == 0)
     return DIDescriptor();
 
-  if (Elt < DbgNode->getNumElements() && DbgNode->getElement(Elt))
-    return DIDescriptor(dyn_cast<MDNode>(DbgNode->getElement(Elt)));
+  if (Elt < DbgNode->getNumOperands() && DbgNode->getOperand(Elt))
+    return DIDescriptor(dyn_cast<MDNode>(DbgNode->getOperand(Elt)));
 
   return DIDescriptor();
 }
@@ -115,8 +115,8 @@
   if (DbgNode == 0)
     return 0;
 
-  if (Elt < DbgNode->getNumElements())
-      return dyn_cast_or_null<GlobalVariable>(DbgNode->getElement(Elt));
+  if (Elt < DbgNode->getNumOperands())
+      return dyn_cast_or_null<GlobalVariable>(DbgNode->getOperand(Elt));
   return 0;
 }
 
@@ -264,7 +264,7 @@
 
 unsigned DIArray::getNumElements() const {
   assert(DbgNode && "Invalid DIArray");
-  return DbgNode->getNumElements();
+  return DbgNode->getNumOperands();
 }
 
 /// replaceAllUsesWith - Replace all uses of debug info referenced by
@@ -886,18 +886,18 @@
   Value *Elts[] = {
     GetTagConstant(dwarf::DW_TAG_subprogram),
     llvm::Constant::getNullValue(Type::getInt32Ty(VMContext)),
-    DeclNode->getElement(2), // Context
-    DeclNode->getElement(3), // Name
-    DeclNode->getElement(4), // DisplayName
-    DeclNode->getElement(5), // LinkageName
-    DeclNode->getElement(6), // CompileUnit
-    DeclNode->getElement(7), // LineNo
-    DeclNode->getElement(8), // Type
-    DeclNode->getElement(9), // isLocalToUnit
+    DeclNode->getOperand(2), // Context
+    DeclNode->getOperand(3), // Name
+    DeclNode->getOperand(4), // DisplayName
+    DeclNode->getOperand(5), // LinkageName
+    DeclNode->getOperand(6), // CompileUnit
+    DeclNode->getOperand(7), // LineNo
+    DeclNode->getOperand(8), // Type
+    DeclNode->getOperand(9), // isLocalToUnit
     ConstantInt::get(Type::getInt1Ty(VMContext), true),
-    DeclNode->getElement(11), // Virtuality
-    DeclNode->getElement(12), // VIndex
-    DeclNode->getElement(13)  // Containting Type
+    DeclNode->getOperand(11), // Virtuality
+    DeclNode->getOperand(12), // VIndex
+    DeclNode->getOperand(13)  // Containting Type
   };
   return DISubprogram(MDNode::get(VMContext, &Elts[0], 14));
 }
@@ -930,7 +930,7 @@
 
   // Create a named metadata so that we do not lose this mdnode.
   NamedMDNode *NMD = M.getOrInsertNamedMetadata("llvm.dbg.gv");
-  NMD->addElement(Node);
+  NMD->addOperand(Node);
 
   return DIGlobalVariable(Node);
 }
@@ -1106,8 +1106,8 @@
   if (!NMD)
     return;
 
-  for (unsigned i = 0, e = NMD->getNumElements(); i != e; ++i) {
-    DIGlobalVariable DIG(cast<MDNode>(NMD->getElement(i)));
+  for (unsigned i = 0, e = NMD->getNumOperands(); i != e; ++i) {
+    DIGlobalVariable DIG(cast<MDNode>(NMD->getOperand(i)));
     if (addGlobalVariable(DIG)) {
       addCompileUnit(DIG.getCompileUnit());
       processType(DIG.getType());
@@ -1289,8 +1289,8 @@
   if (!NMD)
     return 0;
 
-  for (unsigned i = 0, e = NMD->getNumElements(); i != e; ++i) {
-    DIGlobalVariable DIG(cast_or_null<MDNode>(NMD->getElement(i)));
+  for (unsigned i = 0, e = NMD->getNumOperands(); i != e; ++i) {
+    DIGlobalVariable DIG(cast_or_null<MDNode>(NMD->getOperand(i)));
     if (DIG.isNull())
       continue;
     if (DIG.getGlobal() == V)

Modified: llvm/trunk/lib/Bitcode/Writer/BitcodeWriter.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Bitcode/Writer/BitcodeWriter.cpp?rev=92322&r1=92321&r2=92322&view=diff

==============================================================================
--- llvm/trunk/lib/Bitcode/Writer/ValueEnumerator.cpp (original)
+++ llvm/trunk/lib/Bitcode/Writer/ValueEnumerator.cpp Wed Dec 30 19:22:29 2009
@@ -212,8 +212,8 @@
     MDValues.push_back(std::make_pair(MD, 1U));
     MDValueMap[MD] = MDValues.size();
     MDValueID = MDValues.size();
-    for (unsigned i = 0, e = N->getNumElements(); i != e; ++i) {    
-      if (Value *V = N->getElement(i))
+    for (unsigned i = 0, e = N->getNumOperands(); i != e; ++i) {    
+      if (Value *V = N->getOperand(i))
         EnumerateValue(V);
       else
         EnumerateType(Type::getVoidTy(MD->getContext()));
@@ -222,8 +222,8 @@
   }
   
   if (const NamedMDNode *N = dyn_cast<NamedMDNode>(MD)) {
-    for (unsigned i = 0, e = N->getNumElements(); i != e; ++i)
-      EnumerateValue(N->getElement(i));
+    for (unsigned i = 0, e = N->getNumOperands(); i != e; ++i)
+      EnumerateValue(N->getOperand(i));
     MDValues.push_back(std::make_pair(MD, 1U));
     MDValueMap[MD] = Values.size();
     return;
@@ -327,8 +327,8 @@
     }
 
     if (const MDNode *N = dyn_cast<MDNode>(V)) {
-      for (unsigned i = 0, e = N->getNumElements(); i != e; ++i)
-        if (Value *Elem = N->getElement(i))
+      for (unsigned i = 0, e = N->getNumOperands(); i != e; ++i)
+        if (Value *Elem = N->getOperand(i))
           EnumerateOperandType(Elem);
     }
   } else if (isa<MDString>(V) || isa<MDNode>(V))

Modified: llvm/trunk/lib/Linker/LinkModules.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Linker/LinkModules.cpp?rev=92322&r1=92321&r2=92322&view=diff

==============================================================================
--- llvm/trunk/lib/Linker/LinkModules.cpp (original)
+++ llvm/trunk/lib/Linker/LinkModules.cpp Wed Dec 30 19:22:29 2009
@@ -538,8 +538,8 @@
       NamedMDNode::Create(SrcNMD, Dest);
     else {
       // Add Src elements into Dest node.
-      for (unsigned i = 0, e = SrcNMD->getNumElements(); i != e; ++i) 
-        DestNMD->addElement(SrcNMD->getElement(i));
+      for (unsigned i = 0, e = SrcNMD->getNumOperands(); i != e; ++i) 
+        DestNMD->addOperand(SrcNMD->getOperand(i));
     }
   }
 }

Modified: llvm/trunk/lib/Transforms/Utils/CloneFunction.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Transforms/Utils/CloneFunction.cpp?rev=92322&r1=92321&r2=92322&view=diff

==============================================================================
--- llvm/trunk/lib/Transforms/Utils/CloneFunction.cpp (original)
+++ llvm/trunk/lib/Transforms/Utils/CloneFunction.cpp Wed Dec 30 19:22:29 2009
@@ -360,9 +360,9 @@
     NewLoc = UpdateInlinedAtInfo(OrigLocation.getNode(), TheCallMD);
 
   Value *MDVs[] = {
-    InsnMD->getElement(0), // Line
-    InsnMD->getElement(1), // Col
-    InsnMD->getElement(2), // Scope
+    InsnMD->getOperand(0), // Line
+    InsnMD->getOperand(1), // Col
+    InsnMD->getOperand(2), // Scope
     NewLoc
   };
   return MDNode::get(InsnMD->getContext(), MDVs, 4);

Modified: llvm/trunk/lib/VMCore/AsmWriter.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/VMCore/AsmWriter.cpp?rev=92322&r1=92321&r2=92322&view=diff

==============================================================================
--- llvm/trunk/lib/VMCore/AsmWriter.cpp (original)
+++ llvm/trunk/lib/VMCore/AsmWriter.cpp Wed Dec 30 19:22:29 2009
@@ -648,8 +648,8 @@
          I = TheModule->named_metadata_begin(),
          E = TheModule->named_metadata_end(); I != E; ++I) {
     const NamedMDNode *NMD = I;
-    for (unsigned i = 0, e = NMD->getNumElements(); i != e; ++i) {
-      MDNode *MD = dyn_cast_or_null<MDNode>(NMD->getElement(i));
+    for (unsigned i = 0, e = NMD->getNumOperands(); i != e; ++i) {
+      MDNode *MD = dyn_cast_or_null<MDNode>(NMD->getOperand(i));
       if (MD)
         CreateMetadataSlot(MD);
     }
@@ -722,8 +722,8 @@
 void SlotTracker::processNamedMDNode() {
   ST_DEBUG("begin processNamedMDNode!\n");
   mdnNext = 0;
-  for (unsigned i = 0, e = TheNamedMDNode->getNumElements(); i != e; ++i) {
-    MDNode *MD = dyn_cast_or_null<MDNode>(TheNamedMDNode->getElement(i));
+  for (unsigned i = 0, e = TheNamedMDNode->getNumOperands(); i != e; ++i) {
+    MDNode *MD = dyn_cast_or_null<MDNode>(TheNamedMDNode->getOperand(i));
     if (MD)
       CreateMetadataSlot(MD);
   }
@@ -819,8 +819,8 @@
   unsigned DestSlot = mdnNext++;
   mdnMap[N] = DestSlot;
 
-  for (unsigned i = 0, e = N->getNumElements(); i != e; ++i) {
-    const Value *TV = N->getElement(i);
+  for (unsigned i = 0, e = N->getNumOperands(); i != e; ++i) {
+    const Value *TV = N->getOperand(i);
     if (TV)
       if (const MDNode *N2 = dyn_cast<MDNode>(TV))
         CreateMetadataSlot(N2);
@@ -872,9 +872,9 @@
 
 static void WriteMDNodeComment(const MDNode *Node,
 			       formatted_raw_ostream &Out) {
-  if (Node->getNumElements() < 1)
+  if (Node->getNumOperands() < 1)
     return;
-  ConstantInt *CI = dyn_cast_or_null<ConstantInt>(Node->getElement(0));
+  ConstantInt *CI = dyn_cast_or_null<ConstantInt>(Node->getOperand(0));
   if (!CI) return;
   unsigned Val = CI->getZExtValue();
   unsigned Tag = Val & ~LLVMDebugVersionMask;
@@ -908,8 +908,8 @@
     Out << '!' << i << " = metadata ";
     const MDNode *Node = Nodes[i];
     Out << "!{";
-    for (unsigned mi = 0, me = Node->getNumElements(); mi != me; ++mi) {
-      const Value *V = Node->getElement(mi);
+    for (unsigned mi = 0, me = Node->getNumOperands(); mi != me; ++mi) {
+      const Value *V = Node->getOperand(mi);
       if (!V)
         Out << "null";
       else if (const MDNode *N = dyn_cast<MDNode>(V)) {
@@ -919,7 +919,7 @@
       else {
         TypePrinter.print(V->getType(), Out);
         Out << ' ';
-        WriteAsOperandInternal(Out, Node->getElement(mi), 
+        WriteAsOperandInternal(Out, Node->getOperand(mi), 
                                &TypePrinter, &Machine);
       }
       if (mi + 1 != me)
@@ -1231,14 +1231,14 @@
     if (N->isFunctionLocal()) {
       // Print metadata inline, not via slot reference number.
       Out << "!{";
-      for (unsigned mi = 0, me = N->getNumElements(); mi != me; ++mi) {
-        const Value *Val = N->getElement(mi);
+      for (unsigned mi = 0, me = N->getNumOperands(); mi != me; ++mi) {
+        const Value *Val = N->getOperand(mi);
         if (!Val)
           Out << "null";
         else {
-          TypePrinter->print(N->getElement(0)->getType(), Out);
+          TypePrinter->print(N->getOperand(0)->getType(), Out);
           Out << ' ';
-          WriteAsOperandInternal(Out, N->getElement(0), TypePrinter, Machine);
+          WriteAsOperandInternal(Out, N->getOperand(0), TypePrinter, Machine);
         }
         if (mi + 1 != me)
           Out << ", ";
@@ -1478,9 +1478,9 @@
          E = M->named_metadata_end(); I != E; ++I) {
     const NamedMDNode *NMD = I;
     Out << "!" << NMD->getName() << " = !{";
-    for (unsigned i = 0, e = NMD->getNumElements(); i != e; ++i) {
+    for (unsigned i = 0, e = NMD->getNumOperands(); i != e; ++i) {
       if (i) Out << ", ";
-      MDNode *MD = dyn_cast_or_null<MDNode>(NMD->getElement(i));
+      MDNode *MD = dyn_cast_or_null<MDNode>(NMD->getOperand(i));
       Out << '!' << Machine.getMetadataSlot(MD);
     }
     Out << "}\n";
@@ -2138,9 +2138,9 @@
     TypePrinting TypePrinter;
     SlotTable.initialize();
     OS << "!" << N->getName() << " = !{";
-    for (unsigned i = 0, e = N->getNumElements(); i != e; ++i) {
+    for (unsigned i = 0, e = N->getNumOperands(); i != e; ++i) {
       if (i) OS << ", ";
-      MDNode *MD = dyn_cast_or_null<MDNode>(N->getElement(i));
+      MDNode *MD = dyn_cast_or_null<MDNode>(N->getOperand(i));
       if (MD)
         OS << '!' << SlotTable.getMetadataSlot(MD);
       else

Modified: llvm/trunk/lib/VMCore/IntrinsicInst.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/VMCore/IntrinsicInst.cpp?rev=92322&r1=92321&r2=92322&view=diff

==============================================================================
--- llvm/trunk/lib/VMCore/IntrinsicInst.cpp (original)
+++ llvm/trunk/lib/VMCore/IntrinsicInst.cpp Wed Dec 30 19:22:29 2009
@@ -61,11 +61,11 @@
 Value *DbgStopPointInst::getFileName() const {
   // Once the operand indices are verified, update this assert
   assert(LLVMDebugVersion == (7 << 16) && "Verify operand indices");
-  return getContext()->getElement(3);
+  return getContext()->getOperand(3);
 }
 
 Value *DbgStopPointInst::getDirectory() const {
   // Once the operand indices are verified, update this assert
   assert(LLVMDebugVersion == (7 << 16) && "Verify operand indices");
-  return getContext()->getElement(4);
+  return getContext()->getOperand(4);
 }

Modified: llvm/trunk/lib/VMCore/Metadata.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/VMCore/Metadata.cpp?rev=92322&r1=92321&r2=92322&view=diff

==============================================================================
--- llvm/trunk/lib/VMCore/Verifier.cpp (original)
+++ llvm/trunk/lib/VMCore/Verifier.cpp Wed Dec 30 19:22:29 2009
@@ -1538,8 +1538,8 @@
   if (!Visited.insert(N))
     return;
   
-  for (unsigned i = 0, e = N->getNumElements(); i != e; ++i) {
-    Value *V = N->getElement(i);
+  for (unsigned i = 0, e = N->getNumOperands(); i != e; ++i) {
+    Value *V = N->getOperand(i);
     if (!V) continue;
     
     Function *ActualF = 0;

Modified: llvm/trunk/unittests/VMCore/MetadataTest.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/unittests/VMCore/MetadataTest.cpp?rev=92322&r1=92321&r2=92322&view=diff

==============================================================================
--- llvm/trunk/unittests/VMCore/MetadataTest.cpp (original)
+++ llvm/trunk/unittests/VMCore/MetadataTest.cpp Wed Dec 30 19:22:29 2009
@@ -92,13 +92,13 @@
   (void) n3;
 #endif
 
-  EXPECT_EQ(3u, n1->getNumElements());
-  EXPECT_EQ(s1, n1->getElement(0));
-  EXPECT_EQ(CI, n1->getElement(1));
-  EXPECT_EQ(s2, n1->getElement(2));
+  EXPECT_EQ(3u, n1->getNumOperands());
+  EXPECT_EQ(s1, n1->getOperand(0));
+  EXPECT_EQ(CI, n1->getOperand(1));
+  EXPECT_EQ(s2, n1->getOperand(2));
 
-  EXPECT_EQ(1u, n2->getNumElements());
-  EXPECT_EQ(n1, n2->getElement(0));
+  EXPECT_EQ(1u, n2->getNumOperands());
+  EXPECT_EQ(n1, n2->getOperand(0));
 
   std::string Str;
   raw_string_ostream oss(Str);





More information about the llvm-commits mailing list
--- llvm/trunk/include/llvm/Metadata.h (original)
+++ llvm/trunk/include/llvm/Metadata.h Wed Dec 30 19:22:29 2009
@@ -26,7 +26,10 @@
 class LLVMContext;
 class Module;
 template <typename T> class SmallVectorImpl;
-
+template<typename ValueSubClass, typename ItemParentClass>
+  class SymbolTableListTraits;
+  
+  
 //===----------------------------------------------------------------------===//
 // MetadataBase  - A base class for MDNode, MDString and NamedMDNode.
 class MetadataBase : public Value {
@@ -81,16 +84,16 @@
 };
 
   
-class MDNodeElement;
+class MDNodeOperand;
   
 //===----------------------------------------------------------------------===//
 /// MDNode - a tuple of other values.
 class MDNode : public MetadataBase, public FoldingSetNode {
   MDNode(const MDNode &);                // DO NOT IMPLEMENT
   void operator=(const MDNode &);        // DO NOT IMPLEMENT
-  friend class MDNodeElement;
+  friend class MDNodeOperand;
 
   /// NumOperands - This many 'MDNodeElement' items are co-allocated onto the
   /// end of this MDNode.
   unsigned NumOperands;
   
@@ -110,8 +113,8 @@
     DestroyFlag      = 1 << 2
   };
   
-  // Replace each instance of F from the element list of this node with T.
-  void replaceElement(MDNodeElement *Op, Value *NewVal);
+  // Replace each instance of F from the operand list of this node with T.
+  void replaceOperand(MDNodeOperand *Op, Value *NewVal);
   ~MDNode();
 
 protected:
@@ -122,11 +125,11 @@
   static MDNode *get(LLVMContext &Context, Value *const *Vals, unsigned NumVals,
                      bool isFunctionLocal = false);
   
-  /// getElement - Return specified element.
-  Value *getElement(unsigned i) const;
+  /// getOperand - Return specified operand.
+  Value *getOperand(unsigned i) const;
   
-  /// getNumElements - Return number of MDNode elements.
-  unsigned getNumElements() const { return NumOperands; }
+  /// getNumOperands - Return number of MDNode operands.
+  unsigned getNumOperands() const { return NumOperands; }
   
   /// isFunctionLocal - Return whether MDNode is local to a function.
   /// Note: MDNodes are designated as function-local when created, and keep
@@ -165,10 +168,7 @@
 
 //===----------------------------------------------------------------------===//
 /// NamedMDNode - a tuple of other metadata. 
-/// NamedMDNode is always named. All NamedMDNode element has a type of metadata.
-template<typename ValueSubClass, typename ItemParentClass>
-  class SymbolTableListTraits;
-
+/// NamedMDNode is always named. All NamedMDNode operand has a type of metadata.
 class NamedMDNode : public MetadataBase, public ilist_node<NamedMDNode> {
   friend class SymbolTableListTraits<NamedMDNode, Module>;
   friend class LLVMContextImpl;
@@ -205,14 +205,14 @@
   inline Module *getParent() { return Parent; }
   inline const Module *getParent() const { return Parent; }
 
-  /// getElement - Return specified element.
-  MetadataBase *getElement(unsigned i) const;
+  /// getOperand - Return specified operand.
+  MetadataBase *getOperand(unsigned i) const;
   
-  /// getNumElements - Return number of NamedMDNode elements.
-  unsigned getNumElements() const;
+  /// getNumOperands - Return the number of NamedMDNode operands.
+  unsigned getNumOperands() const;
 
-  /// addElement - Add metadata element.
-  void addElement(MetadataBase *M);
+  /// addOperand - Add metadata operand.
+  void addOperand(MetadataBase *M);
   
   /// Methods for support type inquiry through isa, cast, and dyn_cast:
   static inline bool classof(const NamedMDNode *) { return true; }
@@ -81,16 +84,16 @@
 
-  /// NumOperands - This many 'MDNodeElement' items are co-allocated onto the
+  /// NumOperands - This many 'MDNodeOperand' items are co-allocated onto the
   /// end of this MDNode.
   unsigned NumOperands;

Modified: llvm/trunk/lib/Analysis/DebugInfo.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Analysis/DebugInfo.cpp?rev=92322&r1=92321&r2=92322&view=diff

==============================================================================
--- llvm/trunk/lib/Bitcode/Writer/BitcodeWriter.cpp (original)
+++ llvm/trunk/lib/Bitcode/Writer/BitcodeWriter.cpp Wed Dec 30 19:22:29 2009
@@ -475,10 +475,10 @@
                         const ValueEnumerator &VE,
                         BitstreamWriter &Stream,
                         SmallVector<uint64_t, 64> &Record) {
-  for (unsigned i = 0, e = N->getNumElements(); i != e; ++i) {
-    if (N->getElement(i)) {
-      Record.push_back(VE.getTypeID(N->getElement(i)->getType()));
-      Record.push_back(VE.getValueID(N->getElement(i)));
+  for (unsigned i = 0, e = N->getNumOperands(); i != e; ++i) {
+    if (N->getOperand(i)) {
+      Record.push_back(VE.getTypeID(N->getOperand(i)->getType()));
+      Record.push_back(VE.getValueID(N->getOperand(i)));
     } else {
       Record.push_back(VE.getTypeID(Type::getVoidTy(N->getContext())));
       Record.push_back(0);
@@ -535,10 +535,10 @@
       Stream.EmitRecord(bitc::METADATA_NAME, Record, 0/*TODO*/);
       Record.clear();
 
-      // Write named metadata elements.
-      for (unsigned i = 0, e = NMD->getNumElements(); i != e; ++i) {
-        if (NMD->getElement(i))
-          Record.push_back(VE.getValueID(NMD->getElement(i)));
+      // Write named metadata operands.
+      for (unsigned i = 0, e = NMD->getNumOperands(); i != e; ++i) {
+        if (NMD->getOperand(i))
+          Record.push_back(VE.getValueID(NMD->getOperand(i)));
         else
           Record.push_back(0);
       }

Modified: llvm/trunk/lib/Bitcode/Writer/ValueEnumerator.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Bitcode/Writer/ValueEnumerator.cpp?rev=92322&r1=92321&r2=92322&view=diff

==============================================================================
--- llvm/trunk/lib/VMCore/Metadata.cpp (original)
+++ llvm/trunk/lib/VMCore/Metadata.cpp Wed Dec 30 19:22:29 2009
@@ -48,16 +48,16 @@
 }
 
 //===----------------------------------------------------------------------===//
-// MDNodeElement implementation.
+// MDNodeOperand implementation.
 //
 
-// Use CallbackVH to hold MDNode elements.
+// Use CallbackVH to hold MDNode operands.
 namespace llvm {
-class MDNodeElement : public CallbackVH {
+class MDNodeOperand : public CallbackVH {
   MDNode *Parent;
 public:
-  MDNodeElement(Value *V, MDNode *P) : CallbackVH(V), Parent(P) {}
-  ~MDNodeElement() {}
+  MDNodeOperand(Value *V, MDNode *P) : CallbackVH(V), Parent(P) {}
+  ~MDNodeOperand() {}
   
   void set(Value *V) {
     setValPtr(V);
@@ -69,12 +69,12 @@
 } // end namespace llvm.
 
 
-void MDNodeElement::deleted() {
-  Parent->replaceElement(this, 0);
+void MDNodeOperand::deleted() {
+  Parent->replaceOperand(this, 0);
 }
 
-void MDNodeElement::allUsesReplacedWith(Value *NV) {
-  Parent->replaceElement(this, NV);
+void MDNodeOperand::allUsesReplacedWith(Value *NV) {
+  Parent->replaceOperand(this, NV);
 }
 
 
@@ -83,11 +83,11 @@
 // MDNode implementation.
 //
 
 /// getOperandPtr - Helper function to get the MDNodeElement's coallocated on
 /// the end of the MDNode.
-static MDNodeElement *getOperandPtr(MDNode *N, unsigned Op) {
-  assert(Op < N->getNumElements() && "Invalid operand number");
-  return reinterpret_cast<MDNodeElement*>(N+1)+Op;
+static MDNodeOperand *getOperandPtr(MDNode *N, unsigned Op) {
+  assert(Op < N->getNumOperands() && "Invalid operand number");
+  return reinterpret_cast<MDNodeOperand*>(N+1)+Op;
 }
 
 MDNode::MDNode(LLVMContext &C, Value *const *Vals, unsigned NumVals,
@@ -99,9 +99,9 @@
     setValueSubclassData(getSubclassDataFromValue() | FunctionLocalBit);
 
   // Initialize the operand list, which is co-allocated on the end of the node.
-  for (MDNodeElement *Op = getOperandPtr(this, 0), *E = Op+NumOperands;
+  for (MDNodeOperand *Op = getOperandPtr(this, 0), *E = Op+NumOperands;
        Op != E; ++Op, ++Vals)
-    new (Op) MDNodeElement(*Vals, this);
+    new (Op) MDNodeOperand(*Vals, this);
 }
 
 
@@ -115,9 +115,9 @@
   }
   
   // Destroy the operands.
-  for (MDNodeElement *Op = getOperandPtr(this, 0), *E = Op+NumOperands;
+  for (MDNodeOperand *Op = getOperandPtr(this, 0), *E = Op+NumOperands;
        Op != E; ++Op)
-    Op->~MDNodeElement();
+    Op->~MDNodeOperand();
 }
 
 // destroy - Delete this node.  Only when there are no uses.
@@ -139,8 +139,8 @@
   void *InsertPoint;
   MDNode *N = pImpl->MDNodeSet.FindNodeOrInsertPos(ID, InsertPoint);
   if (!N) {
-    // Coallocate space for the node and elements together, then placement new.
-    void *Ptr = malloc(sizeof(MDNode)+NumVals*sizeof(MDNodeElement));
+    // Coallocate space for the node and Operands together, then placement new.
+    void *Ptr = malloc(sizeof(MDNode)+NumVals*sizeof(MDNodeOperand));
     N = new (Ptr) MDNode(Context, Vals, NumVals, isFunctionLocal);
     
     // InsertPoint will have been set by the FindNodeOrInsertPos call.
@@ -149,19 +149,19 @@
   return N;
 }
 
-/// getElement - Return specified element.
-Value *MDNode::getElement(unsigned i) const {
+/// getOperand - Return specified operand.
+Value *MDNode::getOperand(unsigned i) const {
   return *getOperandPtr(const_cast<MDNode*>(this), i);
 }
 
 void MDNode::Profile(FoldingSetNodeID &ID) const {
-  for (unsigned i = 0, e = getNumElements(); i != e; ++i)
-    ID.AddPointer(getElement(i));
+  for (unsigned i = 0, e = getNumOperands(); i != e; ++i)
+    ID.AddPointer(getOperand(i));
 }
 
 
-// Replace value from this node's element list.
-void MDNode::replaceElement(MDNodeElement *Op, Value *To) {
+// Replace value from this node's operand list.
+void MDNode::replaceOperand(MDNodeOperand *Op, Value *To) {
   Value *From = *Op;
   
   if (From == To)
@@ -233,10 +233,10 @@
 NamedMDNode *NamedMDNode::Create(const NamedMDNode *NMD, Module *M) {
   assert(NMD && "Invalid source NamedMDNode!");
   SmallVector<MetadataBase *, 4> Elems;
-  Elems.reserve(NMD->getNumElements());
+  Elems.reserve(NMD->getNumOperands());
   
-  for (unsigned i = 0, e = NMD->getNumElements(); i != e; ++i)
-    Elems.push_back(NMD->getElement(i));
+  for (unsigned i = 0, e = NMD->getNumOperands(); i != e; ++i)
+    Elems.push_back(NMD->getOperand(i));
   return new NamedMDNode(NMD->getContext(), NMD->getName().data(),
                          Elems.data(), Elems.size(), M);
 }
@@ -246,19 +246,19 @@
   delete &getNMDOps(Operands);
 }
 
-/// getNumElements - Return number of NamedMDNode elements.
-unsigned NamedMDNode::getNumElements() const {
+/// getNumOperands - Return number of NamedMDNode operands.
+unsigned NamedMDNode::getNumOperands() const {
   return (unsigned)getNMDOps(Operands).size();
 }
 
-/// getElement - Return specified element.
-MetadataBase *NamedMDNode::getElement(unsigned i) const {
-  assert(i < getNumElements() && "Invalid element number!");
+/// getOperand - Return specified operand.
+MetadataBase *NamedMDNode::getOperand(unsigned i) const {
+  assert(i < getNumOperands() && "Invalid Operand number!");
   return getNMDOps(Operands)[i];
 }
 
-/// addElement - Add metadata element.
-void NamedMDNode::addElement(MetadataBase *M) {
+/// addOperand - Add metadata Operand.
+void NamedMDNode::addOperand(MetadataBase *M) {
   getNMDOps(Operands).push_back(TrackingVH<MetadataBase>(M));
 }
 
@@ -83,11 +83,11 @@
 //
 
-/// getOperandPtr - Helper function to get the MDNodeElement's coallocated on
+/// getOperandPtr - Helper function to get the MDNodeOperand's coallocated on
 /// the end of the MDNode.

Modified: llvm/trunk/lib/VMCore/Verifier.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/VMCore/Verifier.cpp?rev=92322&r1=92321&r2=92322&view=diff

==============================================================================